# Example.pm - The Object class that provides the Example Application Object.
# Created by James A. Pattie, 07/11/2000.

package Portal::Example;
# Copyright (c) 2000, 2001 PC & Web Xperience, Inc. http://www.pcxperience.com/
# All rights reserved.  This program is free software; you can redistribute it
# and/or modify it under the same terms as Perl itself.

use strict;
use Portal::App;
use vars qw($AUTOLOAD $VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Portal::App Exporter AutoLoader);
@EXPORT = qw();

$VERSION = '0.0.12';

# global variables
my %states = ( Main => "Main Menu", );

=head1 NAME

Example - Object used to build a Example Class.

=head1 SYNOPSIS

  use Portal::Example;
  my $obj = Portal::Example->new;
  if ($obj->error())
  {
    die $obj->errorMessage();
  }

=head1 DESCRIPTION

Example is the main class for the Example Application.

=head1 Exported FUNCTIONS

B<NOTE>: I<bool> = 1(true), 0(false)

=over 4

=item scalar new()

 Creates a new instance of the Portal::Example object.
 See Portal::App(3) for a listing of required arguments.

=cut

sub new
{
  my $class = shift;
  my $self = $class->SUPER::new(@_);
  my %args = ( @_ );

  if ($self->error)
  {
    $self->prefixError();
    return $self;
  }

  # instantiate anything unique to this module
  $self->{app} = "Example";
  $self->{appVersion} = $VERSION;
  $self->{states} = \%states;
  $self->{logOk} = 1;  # we can log safely.  Change to 0 if you don't have a log_tb defined in your database.
  $self->{useAppStateCommandSecurity} = 0;

  # do validation
  if (!$self->Portal::Example::isValid)
  {
    # the error is set in the isValid() method.
    return $self;
  }

  # do anything else you might need to do.

  # change the dbHost => "App" when you use this as a template and your 
  # application creates its own database and does not use the Portal's database.
  # That is the literal string "App" not the name of this application.

  $self->instantiatePortalApp(dbHost => "Portal");
  if ($self->error)
  {
    $self->prefixError();
    return $self;
  }

  return $self;
}

=item % getStates(void)

  This method returns the states hash and is only to be
  used by the registerApp method for creating the permissions,
  if using the AppStateCommandSecurity implementation.

=cut
sub getStates
{
  return %states;
}

=item bool isValid(void)

 Returns 0 or 1 to indicate if the object is valid.
 The error will be available via errorMessage().

=cut

sub isValid
{
  my $self = shift;

  # make sure our Parent class is valid.
  if (!$self->SUPER::isValid())
  {
    $self->prefixError();
    return 0;
  }

  # validate our parameters.

  if ($self->numInvalid() > 0 || $self->numMissing() > 0)
  {
    $self->error($self->genErrorString("all"));
    return 0;
  }

  return 1;
}

=back

=cut

1;
__END__

=head1 NOTE

 All data fields are accessible by specifying the object
 and pointing to the data member to be modified on the
 left-hand side of the assignment.
 Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

PC&Web Xperience, Inc. (mailto:admin@pcxperience.com)

=head1 SEE ALSO

perl(1), Portal(3), Portal::Example(3), Portal::App(3)

=cut

